<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:fnbcl="http://www.bcl.lu/2006/bcl-xpath-functions"
	version="2.0">
	<xsl:import href="../functions/BcL_functions.xsl"/>
	
	<xsl:output method="text" />
	
	
	
	<xsl:variable name="COMPONENT_SEPARATOR" select="':'" />
	<xsl:variable name="SEGMENT_SEPARATOR" select="'+'" />
	<xsl:variable name="DECIMAL_CHARACTER" select="'.'" />
	<xsl:variable name="RELEASE_CHARACTER" select="'?'" />
	<xsl:variable name="SPACE_CHARACTER" select="' '" />
	<xsl:variable name="SEGMENT_TERMINATOR" select="''''" />
	<xsl:variable name="EOL" select="'&#xD;&#xA;'" />
	
	
	<xsl:variable name="NB_SEGMENTS_FIXES" select="17"/>
	
	<xsl:template name="EDIFACT-UNA">
		<xsl:comment>UNA Service String Advise...</xsl:comment>
		<xsl:value-of select="'UNA'" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$DECIMAL_CHARACTER" />
		<xsl:value-of select="$RELEASE_CHARACTER" />
		<xsl:value-of select="$SPACE_CHARACTER" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...UNA Service String Advise</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-UNB">
		<xsl:param name="cdIdentAc"/>
		<xsl:param name="dtCre" as="xs:dateTime"/>
		<xsl:param name="motPasAc"/>
		<xsl:param name="formatDateCd"/>
		<xsl:variable name="dtCreTemp" select="format-dateTime($dtCre, '[Y01][M01][D01]', $formatDateCd, (), ())" />
		<xsl:variable name="year" select="substring($dtCreTemp, 3, 2)" />
		<xsl:comment>UNB Interchange Header...</xsl:comment>
		<xsl:value-of select="'UNB'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'UNOA'" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="'1'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$cdIdentAc" />
		<xsl:value-of select="'-FINREP-LU'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'IML-FINREP-LU'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="substring($dtCreTemp, 3, 6 )" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="format-dateTime($dtCre, '[H01][m01]', $formatDateCd, (), ())" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$cdIdentAc" />
		<xsl:value-of select="$year" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="fnbcl:edifact-encode($motPasAc)" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...UNB Interchange Header</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-UNH">
		<xsl:param name="cdIdentAc"/>
		<xsl:param name="dtCre" as="xs:dateTime"/>
		<xsl:param name="numMess"/>
		<xsl:param name="formatDateCd"/>
		<xsl:variable name="dtCreTemp" select="format-dateTime($dtCre, '[Y01]', $formatDateCd, (), ())" />
		<xsl:variable name="year" select="substring($dtCreTemp, 3, 2)" />
		<xsl:comment>UNH Message Header...</xsl:comment>
		<xsl:value-of select="'UNH'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$cdIdentAc" />
		<xsl:value-of select="$year" />
		<xsl:value-of select="format-number($numMess, '00000')" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'FINREP'" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="'1'" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="'911'" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="'UN'" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...UNH Message Header</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-BGM">
		<xsl:param name="typeRapport"/>
		<xsl:comment>BGM Beginning of the Message...</xsl:comment>
		<xsl:value-of select="'BGM'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'411'" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="'ZZZ'" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="'5'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$typeRapport" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'9'" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...BGM Beginning of the Message</xsl:comment>
	</xsl:template>

	<xsl:template name="EDIFACT-DTM">
		<xsl:param name="typeDate"/>
		<xsl:param name="date" as="xs:dateTime"/>
		<xsl:param name="formatDateCd"/>
		<xsl:comment>DTM Date/Time Period...</xsl:comment>
		<xsl:value-of select="'DTM'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$typeDate" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of
			select="format-dateTime($date, '[Y0001][M01][D01][H01][m01]', $formatDateCd, (), ())" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="'203'" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...DTM Date/Time Period</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-PEI">
		<xsl:param name="periode"/>
		<xsl:param name="dtDebRap" as="xs:date"/>
		<xsl:param name="dtFinRap" as="xs:date"/>
		<xsl:param name="formatDateCd"/>
		<xsl:comment>PEI Identification of the Period...</xsl:comment>
		<xsl:value-of select="'PEI'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$periode" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'183'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of
			select="format-date($dtDebRap, '[Y0001][M01][D01]', $formatDateCd, (), ())" />
		<xsl:value-of
			select="format-date($dtFinRap, '[Y0001][M01][D01]', $formatDateCd, (), ())" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'718'" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...PEI Identification of the Period</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-SJS">
		<xsl:param name="cdStructJurOpc"/>
		<xsl:param name="codifInstrFonds"/>
		<xsl:param name="codifInstrCompart"/>
		<xsl:comment>SJS Legal Status of the company...</xsl:comment>
		<xsl:value-of select="'SJS'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$cdStructJurOpc" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'O'" />
		<xsl:value-of select="format-number($codifInstrFonds, '000000')" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="'ZZZ'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="format-number($codifInstrCompart, '00000')" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...SJS Legal Status of the company</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-NAD">
		<xsl:param name="libAbrInstr"/>
		<xsl:param name="adr"/>
		<xsl:param name="ville"/>
		<xsl:param name="cdPostal"/>
		<xsl:param name="pays"/>
		<xsl:comment>NAD Name and Address...</xsl:comment>
		<xsl:value-of select="'NAD'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'DT'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of
			select="fnbcl:string-cut(fnbcl:edifact-encode($libAbrInstr), $COMPONENT_SEPARATOR, 35, 5)" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of
			select="fnbcl:string-cut(fnbcl:edifact-encode($adr), $COMPONENT_SEPARATOR, 35, 3)" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of
			select="fnbcl:string-cut(fnbcl:edifact-encode($ville), $COMPONENT_SEPARATOR, 35, 1)" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of
			select="fnbcl:string-cut(fnbcl:edifact-encode($cdPostal), $COMPONENT_SEPARATOR, 9, 1)" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$pays" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...NAD Name and Address</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-CTA">
		<xsl:param name="titre"/>
		<xsl:param name="prenom"/>
		<xsl:param name="nom"/>
		<xsl:comment>CTA Contacts...</xsl:comment>
		<xsl:value-of select="'CTA'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'AD'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:variable name="contact">
			<xsl:value-of select="$titre" />
			<xsl:value-of
				select="
				if ($prenom ne '')
				then concat($SPACE_CHARACTER, $prenom)
				else ()" />
			<xsl:value-of
				select="
				if ($nom ne '')
				then concat($SPACE_CHARACTER, $nom)
				else ()" />
		</xsl:variable>
		<xsl:value-of
			select="fnbcl:string-cut(fnbcl:edifact-encode($contact), $COMPONENT_SEPARATOR, 35, 1)" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...CTA Contacts</xsl:comment>
	</xsl:template>

	<xsl:template name="EDIFACT-COM">
		<xsl:param name="tel"/>
		<xsl:comment>COM Communication Contact...</xsl:comment>
		<xsl:value-of select="'COM'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of
			select="fnbcl:string-cut(fnbcl:edifact-encode($tel), $COMPONENT_SEPARATOR, 55, 1)" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="'TE'" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...COM Communication Contact</xsl:comment>
	</xsl:template>

	<xsl:template name="EDIFACT-CUX">
		<xsl:param name="cdDevIso"/>
		<xsl:param name="txChgeIml"/>
		<xsl:comment>CUX Currencies...</xsl:comment>
		<xsl:value-of select="'CUX'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'2'" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="$cdDevIso" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$txChgeIml" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...CUX Currencies</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-UNS">
		<xsl:param name="type"/>	
		<xsl:comment>UNS Section control...</xsl:comment>
		<xsl:value-of select="'UNS'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$type" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...UNS Section control</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-CPT">
		<xsl:param name="coded-account" as="xs:string"/>
		<xsl:comment>CPT Account Number...</xsl:comment>
		<xsl:value-of select="'CPT'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'DET'" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="$coded-account" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...CPT Account Number</xsl:comment>
	</xsl:template>	
	
	<xsl:template name="EDIFACT-VAL">
		<xsl:param name="type"/>
		<xsl:param name="montant" as="xs:decimal"/>
		<xsl:comment>VAL Stated Value...</xsl:comment>
		<xsl:value-of select="'VAL'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
	 	<xsl:value-of select="$type"/>
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="abs($montant)" />
		<xsl:choose>
			<xsl:when test="$montant lt 0">
				<xsl:value-of select="$SEGMENT_SEPARATOR" />
				<xsl:value-of select="'DB'" />
			</xsl:when>
			<xsl:when test="$montant ge 0">
				<xsl:value-of select="$SEGMENT_SEPARATOR" />
				<xsl:value-of select="'CD'" />
			</xsl:when>
		</xsl:choose>
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...VAL Stated Value</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-QTY">
		<xsl:param name="compteur"/>
		<xsl:comment>QTY Quantity...</xsl:comment>
		<xsl:value-of select="'QTY'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'140'" />
		<xsl:value-of select="$COMPONENT_SEPARATOR" />
		<xsl:value-of select="$compteur"/>
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...QTY Quantity</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-AUT">
		<xsl:param name="cdAuthent"/>
		<xsl:comment>AUT Authentification Result...</xsl:comment>
		<xsl:value-of select="'AUT'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$cdAuthent"/>
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...AUT Authentification Result</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-UNT">
		<xsl:param name="nbSegments"/>
		<xsl:param name="cdIdentAc"/>
		<xsl:param name="dtCre" as="xs:dateTime"/>
		<xsl:param name="numMess"/>
		<xsl:param name="formatDateCd"/>
		<xsl:variable name="dtCreTemp" select="format-dateTime($dtCre, '[Y01]', $formatDateCd, (), ())" />
		<xsl:variable name="year" select="substring($dtCreTemp, 3, 2)" />
		<xsl:comment>UNT Message Trailer...</xsl:comment>
		<xsl:value-of select="'UNT'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$nbSegments" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$cdIdentAc" />
		<xsl:value-of select="$year" />
		<xsl:value-of select="format-number($numMess, '00000')" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...UNT Message Trailer</xsl:comment>
	</xsl:template>

	<xsl:template name="EDIFACT-UNZ">
		<xsl:param name="cdIdentAc"/>
		<xsl:param name="dtCre" as="xs:dateTime"/>
		<xsl:param name="formatDateCd"/>
		<xsl:variable name="dtCreTemp" select="format-dateTime($dtCre, '[Y01]', $formatDateCd, (), ())" />
		<xsl:variable name="year" select="substring($dtCreTemp, 3, 2)" />
		<xsl:comment>UNZ Interchane Control Trailer...</xsl:comment>
		<xsl:value-of select="'UNZ'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="'1'" />
		<xsl:value-of select="$SEGMENT_SEPARATOR" />
		<xsl:value-of select="$cdIdentAc" />
		<xsl:value-of select="$year" />
		<xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
		<xsl:comment>...UNZ Interchane Control Trailer</xsl:comment>
	</xsl:template>
	
	<xsl:template name="EDIFACT-FTX">
		<xsl:comment>FTX Free Text...</xsl:comment>
		<xsl:value-of select="'FTX+ALL+BOURSE DE LUXEMBOURG;3.0:EFILE;3.0'" />
    <xsl:value-of select="$SEGMENT_TERMINATOR" />
		<xsl:value-of select="$EOL" />
	</xsl:template>
	
</xsl:stylesheet>
